"use strict";

var isImplemented = require("../../../../string/#/starts-with/is-implemented");

module.exports = function (a) { a(isImplemented(), true); };
